Crate lemmy_api_common

Crate lemmy_api_common 

Modules

account
comment
community
custom_emoji
error
federation
language
media
modlog
notification
oauth
person
plugin
post
private_message
report
site
tagline

Structs

DbUrl
PagedResponse
This response contains only a single page of items. To get the next page, take the cursor string from next_page and pass it to the same API endpoint via page_cursor parameter. For going to the previous page, use prev_page instead.
PaginationCursor
To get the next or previous page, pass this string unchanged as page_cursor in a new request to the same endpoint.
SensitiveString
SuccessResponse
A response that completes successfully.
VoteView
A vote view for checking a post or comments votes.

Enums

VoteShow
Lets you show votes for others only, show all votes, or hide all votes.