Modules
- account
- comment
- community
- custom_
emoji - error
- federation
- language
- media
- modlog
- notification
- oauth
- person
- plugin
- post
- private_
message - report
- site
- tagline
Structs
- DbUrl
- Paged
Response - This response contains only a single page of items. To get the next page, take the
cursor string from
next_pageand pass it to the same API endpoint viapage_cursorparameter. For going to the previous page, useprev_pageinstead. - Pagination
Cursor - To get the next or previous page, pass this string unchanged as
page_cursorin a new request to the same endpoint. - Sensitive
String - Success
Response - A response that completes successfully.
- Vote
View - A vote view for checking a post or comments votes.
Enums
- Vote
Show - Lets you show votes for others only, show all votes, or hide all votes.